@@ -178,7 +178,7 @@ Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustrin
 }
 
 
-Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const type_sort_clause& sort_clause)
+Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const Glib::ustring& extra_join, const type_sort_clause& sort_clause, const Glib::ustring& extra_group_by)
 {
   //TODO_Performance:
   type_vecConstLayoutFields constFieldsToGet;
@@ -187,11 +187,11 @@ Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& tab
     constFieldsToGet.push_back(*iter);
   }
 
-  return build_sql_select_with_where_clause(table_name, constFieldsToGet, where_clause, sort_clause);
+  return build_sql_select_with_where_clause(table_name, constFieldsToGet, where_clause, extra_join, sort_clause, extra_group_by);
 }
 
 
-typedef std::list< sharedptr<const UsesRelationship> > type_list_relationships;
+static typedef std::list< sharedptr<const UsesRelationship> > type_list_relationships;
 
 static void add_to_relationships_list(type_list_relationships& list_relationships, const sharedptr<const LayoutItem_Field>& layout_item)
 {
@@ -220,7 +220,7 @@ static void add_to_relationships_list(type_list_relationships& list_relationship
  
 }
 
-Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecConstLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const type_sort_clause& sort_clause)
+Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecConstLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const Glib::ustring& extra_join, const type_sort_clause& sort_clause, const Glib::ustring& extra_group_by)
 {
   Glib::ustring result;
 
@@ -313,6 +313,11 @@ Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& tab
     }
   }
 
+  if(!extra_join.empty())
+  {
+    sql_part_leftouterjoin += (" " + extra_join + " ");
+  }
+
   if(!sql_part_from.empty())
     result += ("," + sql_part_from);
 
@@ -344,6 +349,11 @@ Glib::ustring Utils::build_sql_select_with_where_clause(const Glib::ustring& tab
       result += " ORDER BY " + str_sort_clause;
   }
 
+  if(!extra_group_by.empty())
+  {
+    result += (" " + extra_group_by + " ");
+  }
+
   return result;
 }
 
