@@ -330,24 +330,6 @@ Gtk::TreeModel::iterator DbAddDel::get_item_placeholder()
   return m_refListStore->get_placeholder_row();
 }
 
-void DbAddDel::remove_all()
-{
-  InnerIgnore innerIgnore(this); //see comments for InnerIgnore class.
-
-/* TODO
-  if(m_refListStore)
-  {
-    Gtk::TreeModel::iterator iter = m_refListStore->children().begin();
-    while(iter)
-    {
-      m_refListStore->erase(iter);
-      iter = m_refListStore->children().begin();
-    }
-  }
-*/
-}
-
-
 Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, const sharedptr<const LayoutItem_Field>& layout_item)
 {
   Gnome::Gda::Value value;
@@ -754,6 +736,8 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
 
 void DbAddDel::construct_specified_columns()
 {
+  //std::cout << "debug: DbAddDel::construct_specified_columns" << std::endl;
+
   InnerIgnore innerIgnore(this);
 
   //TODO_optimisation: This is called many times, just to simplify the API.
@@ -920,6 +904,10 @@ void DbAddDel::construct_specified_columns()
 
 bool DbAddDel::refresh_from_database()
 {
+  construct_specified_columns();
+  return true;
+
+  /*
   if(m_refListStore)
   {
     //Glib::RefPtr<Gtk::TreeModel> refNull;
@@ -933,6 +921,7 @@ bool DbAddDel::refresh_from_database()
   }
   else
     return false;
+  */
 }
 
 bool DbAddDel::refresh_from_database_blank()
